@@ -4,19 +4,37 @@ import inspect
 import os
 
 import mngs
+import warnings
 
-# import git
+
+if "general" in __file__:
+    with warnings.catch_warnings():
+        warnings.simplefilter("always")
+        warnings.warn(
+            '\n"mngs.general.path" will be removed. '
+            'Please use "mngs.io.path" instead.',
+            PendingDeprecationWarning,
+        )
 
 
 ################################################################################
 ## PATH
 ################################################################################
+def get_this_fpath(when_ipython="/tmp/fake.py"):
+    __file__ = inspect.stack()[1].filename
+    if "ipython" in __file__:  # for ipython
+        __file__ = when_ipython  # "/tmp/fake.py"
+    return __file__
+
+
 def mk_spath(sfname, makedirs=False):
 
     __file__ = inspect.stack()[1].filename
     if "ipython" in __file__:  # for ipython
         __file__ = "/tmp/fake.py"
 
+    # __file__ = get_current_file_name()
+
     ## spath
     fpath = __file__
     fdir, fname, _ = split_fpath(fpath)
@@ -30,6 +48,8 @@ def mk_spath(sfname, makedirs=False):
 
 
 def find_the_git_root_dir():
+    import git
+
     repo = git.Repo(".", search_parent_directories=True)
     return repo.working_tree_dir
 
@@ -46,3 +66,8 @@ def split_fpath(fpath):
     base = os.path.basename(fpath)
     fname, ext = os.path.splitext(base)
     return dirname, fname, ext
+
+def touch(fpath):
+    import pathlib
+    return pathlib.Path(fpath).touch()
+    
